Learn R Programming

obcost (version 0.1.0)

obesity_cost_disease: Relevant Data for Obesity, Cost, and Diseases

Description

This dataset gives supplementary output with all variables related to individual disease groups in a given state and year.

State

state of interest

Year

year of interest

pi_it

obesity prevalence in state i and year t

cause

disease group

rr_j

relative risk of disease group j on obesity

psi_jt

national cost of disease group j in year t

rho_jit

population-attributable risk percent of disease group j in state i and year t

DC_jit

direct cost for disease group j in state i and year t

Usage

obesity_cost_disease

Arguments

Format

An object of class data.frame with 10350 rows and 8 columns.